For beginners
=============

Getting started
---------------

Abjad makes powerful programming techniques available to you when you compose.
Read through the points below and then click next to proceed.


Knowing your operating system
`````````````````````````````

Before you start working with Abjad you should review the command line basics
of your operating system. You should know how move around the filesystem, how
to list the contents of directories and how to copy files. You should know
enough about environment variables to make sure that your operating system
knows where Abjad is installed. You might also consider installing any OS
updates on your computer, too, since you'll need Python 2.7 or Python 3.3+ to
run Abjad. When you start building scores with Abjad you'll find the system to
be almost entirely platform-independent.


Chosing a text editor
`````````````````````

You'll edit many text files when you work with Abjad. So you'll want to spend
some time picking out a text editor before you begin. If this is your first
time programming you might want to Google and read what other programmers have
to say on the matter. Or you could ask a programmer friend about the editor she
prefers. Linux programmers sometimes like ``vi`` or ``emacs``. Macintosh
programmers might prefer ``TextMate``. Whatever your choice, make sure
your editor is set to produce plain text files before you start.


Launching the terminal
``````````````````````

To work with Abjad you'll need a terminal window. The way that you open the
terminal window depends on your computer. If you're using MacOS X you can
navigate from ``Applications`` to ``Utilities`` and then click on ``Terminal``.
Linux and Windows house the terminal elsewhere. Regardless of the terminal
client you choose, the purpose of the terminal is to let you type commands to
your computer's operating system.


Where to save your work
```````````````````````

Where you choose to save the files you create with Abjad is up to you.
Eventually you'll want to create a dedicated set of directories to organize
your work. But for now you can create the files described in the tutorials on
your desktop, in your documents folder, or anywhere else you like.

Introducing LilyPond
--------------------

..  toctree::
    :maxdepth: 1

    lilypond_hello_world
    more_about_lilypond

Introducing Python
------------------

..  toctree::
    :maxdepth: 1

    python_hello_world_at_the_interpreter
    python_hello_world_in_a_file
    more_about_python

Introducing Abjad
-----------------

..  toctree::
    :maxdepth: 1

    abjad_hello_world_at_the_interpreter
    abjad_hello_world_in_a_file
    more_about_abjad
